@@ -17,7 +17,7 @@ class Accountant:
 
     def __init__(self, bank_account):
         self.bank_account = bank_account
-        self.ledger = LedgerClient(ledger_host="http://internal-prod-internal-loadbalancer-874786328.ap-southeast-1.elb.amazonaws.com")
+        self.ledger = LedgerClient(ledger_host="http://internal-prod-internal-loadbalancer-874786328.ap-southeast-1.elb.amazonaws.com/")
 
         log.info("---------Initialising-------------")
         log.info(f"Bank Account Number:  {self.bank_account['account_id']}")
@@ -149,9 +149,9 @@ class Accountant:
     @staticmethod
     def create_book(account_id: str):
         log.info("---------New_ledger-------------")
-        ledger = LedgerClient(ledger_host="http://internal-prod-internal-loadbalancer-874786328.ap-southeast-1.elb.amazonaws.com")
-        block_book_id = ledger.create_book(name=f"{account_id}_block_book", min_balance=0)
-        main_book_id = ledger.create_book(name=f"{account_id}_main_book", min_balance=0)
+        ledger = LedgerClient(ledger_host="http://internal-prod-internal-loadbalancer-874786328.ap-southeast-1.elb.amazonaws.com/")
+        block_book_id = ledger.create_book(name=f"{account_id}_block_book", min_balance="0")
+        main_book_id = ledger.create_book(name=f"{account_id}_main_book", min_balance="0")
         new_books = {
             'main_balance': {'name': main_book_id['name'],
                              'id': main_book_id['id']},
